OC.L10N.register(
    "dav",
    {
    "Calendar" : "Naptár",
    "Todos" : "Teendők",
    "Personal" : "Személyes",
    "{actor} created calendar {calendar}" : "{actor} létrehozta a naptárt: {calendar}",
    "You created calendar {calendar}" : "Létrehoztad a naptárt: {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} törölte a naptárt: {calendar}",
    "You deleted calendar {calendar}" : "Törölted a naptárt: {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} frissítette a napárt: {calendar}",
    "You updated calendar {calendar}" : "Frissítetted a naptárt: {calendar}",
    "You shared calendar {calendar} as public link" : "Nyilvános hivatkozásként megosztottad ezt a naptárt: {calendar}",
    "You removed public link for calendar {calendar}" : "Eltávolítottad a naptár nyilvános hivatkozását: {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} megosztotta veled ezt a naptárt: {calendar}",
    "You shared calendar {calendar} with {user}" : "Megosztottad ezt a napárt: {calendar} vele: {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} megosztotta ezt a napárt: {calendar} vele: {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} visszavonta töled a naptár megosztását: {calendar}",
    "You unshared calendar {calendar} from {user}" : "Visszavontad a naptár megosztását: {calendar} tőle: {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} visszavonta a naptár megosztását: {calendar} tőle: {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} visszavonta tőlük a naptár megosztását: {calendar}",
    "You shared calendar {calendar} with group {group}" : "Megosztottad ezt a naptárt: {calendar} evvel a csoporttal: {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} megosztotta ezt a naptárt: {calendar} evvel a csoporttal: {group}",
    "You unshared calendar {calendar} from group {group}" : "Visszavontad ennek a naptárnak a magosztását: {calendar} ettől a csoporttól: {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} visszavonta ennek a naptárnak a magosztását: {calendar} ettől a csoporttól: {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} létrehozta ezt az eseményt: {event} ebben a naptárban: {calendar}",
    "You created event {event} in calendar {calendar}" : "Létrehoztad ezt az eseményt: {event} ebben a naptárban: {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} törölte ezt az eseményt: {event} ebből a naptárból: {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Törölted ezt az eseményt: {event} ebből a naptárból: {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} frissítette ezt az eseményt: {event} ebben a naptárban: {calendar}",
    "You updated event {event} in calendar {calendar}" : "Frissítetted ezt az eseményt: {event} ebben a naptárban: {calendar}",
    "Busy" : "Foglalt",
    "{actor} created todo {todo} in list {calendar}" : "{actor} létrehozta ezt a teendőt: {todo} ebben a listában: {calendar}",
    "You created todo {todo} in list {calendar}" : "Létrehoztad ezt a teendőt: {todo} ebben a listában: {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} törölte ezt a teendőt: {todo} ebből a listából: {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Törölted ezt a teendőt: {todo} ebből a listából: {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} frissítette ezt a teendőt: {todo} ebben a listában: {calendar}",
    "You updated todo {todo} in list {calendar}" : "Frissítetted ezt a teendőt: {todo} ebben a listában: {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} elintézte ezt a teendőt: {todo} ebben a listában: {calendar}",
    "You solved todo {todo} in list {calendar}" : "Elintézted ezt a teendőt: {todo} ebben a listában: {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} újranyitotta ezt a teendőt: {todo} ebben a listában: {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Újranyitottad ezt a teendőt: {todo} ebben a listában: {calendar}",
    "A <strong>calendar</strong> was modified" : "Egy <strong>naptár</strong> megváltozott",
    "A calendar <strong>event</strong> was modified" : "Egy naptár <strong>esemény</strong> megváltozott",
    "A calendar <strong>todo</strong> was modified" : "Egy naptár <strong>teendő</strong> megváltozott",
    "Contact birthdays" : "Születésnapok",
    "Where:" : "Hol:",
    "Description:" : "Leírás:",
    "%1$s via %2$s" : "%1$s - %2$s",
    "Invitation canceled" : "Meghívás visszavonva",
    "Hello %s," : "Üdv %s,",
    "The meeting »%1$s« with %2$s was canceled." : "A »%1$s« találkozó vele: %2$s lemondásra került.",
    "Invitation updated" : "Meghívó frissítve",
    "The meeting »%1$s« with %2$s was updated." : "A »%1$s« találkozó vele:%2$s módosult.",
    "%1$s invited you to »%2$s«" : "%1$s meghívott ide: »%2$s«",
    "When:" : "Mikor:",
    "Link:" : "Link:",
    "Accept" : "Elfogad",
    "Decline" : "Elutasít",
    "More options …" : "További opciók ...",
    "More options at %s" : "További opciók itt: %s",
    "Contacts" : "Névjegyek",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV végpont",
    "Technical details" : "Technikai adatok",
    "Remote Address: %s" : "Távoli cím: %s",
    "Request ID: %s" : "Kérelem azonosító: %s",
    "There was an error updating your attendance status." : "Probléma lépett fel a részvételed státuszának frissítése közben.",
    "Please contact the organizer directly." : "Kérlek vedd fel közvetlenül a kapcsolatot a szervezővel.",
    "Are you accepting the invitation?" : "Elfogadod az meghívást?",
    "Tentative" : "Valószínűleg",
    "Save" : "Mentés",
    "Your attendance was updated successfully." : "A részvételed frissítése sikerült.",
    "Calendar server" : "Naptár szerver",
    "Send invitations to attendees" : "Meghívó küldése a résztvevőknek",
    "Automatically generate a birthday calendar" : "Születésnapokat tartalmazó naptár automatikus létrehozása",
    "Birthday calendars will be generated by a background job." : "A születésnapokat tartalmazó naptárakat egy háttérben futó folyamat fogja létrehozni.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Nem lesznek elérhetőek azonnal az engedélyezés után, de egy rövid idő múlva már láthatóak lesznek.",
    "Please make sure to properly set up the email settings above." : "Győződj meg róla, hogy a fenti e-mail beállítások helyesek."
},
"nplurals=2; plural=(n != 1);");
